==> haskell-wai-http2-extra-0.1.3-365-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-7aWA6w4WnPAAtv124zkVft
key:                  wai-http2-extra-0.1.3-7aWA6w4WnPAAtv124zkVft
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  4a567200dbe3d88ed7c27708f42313c0
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-7aWA6w4WnPAAtv124zkVft
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    psqueues-0.2.8.2-7Hsdb7lcqdu8EEvCE8H06F
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj warp-3.4.0-HpC7vpiyF2eriPYOziTRJ
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-http2-extra-0.1.3-367-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-5I3W3IDoy4YFjqZD6yPTKW
key:                  wai-http2-extra-0.1.3-5I3W3IDoy4YFjqZD6yPTKW
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  af11591b494d9f23ba8d933a41502cd7
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-5I3W3IDoy4YFjqZD6yPTKW
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    psqueues-0.2.8.2-8uu3DxPW2eP1IKqIpq0lUH
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63 warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
